@@ -719,12 +719,30 @@ def get_wake(
     if wake_system == "raven":
         wake_command = ["rhasspy-wake-raven-hermes"]
 
-        template_dir = profile.get("wake.raven.template_dir")
-        if template_dir:
+        template_dir = profile.get("wake.raven.template_dir", "raven")
+        if not template_dir:
+            _LOGGER.error("wake.raven.template_dir is required")
+            return []
+
+        keywords = profile.get("wake.raven.keywords", {})
+        if not keywords:
+            keywords = {"default": {}}
+
+        for keyword_dir_name, keyword_settings in keywords.items():
+            # Add keyword as a directory relative to the template dir
             wake_command.extend(
-                ["--template-dir", shlex.quote(str(write_path(profile, template_dir)))]
+                [
+                    "--keyword",
+                    shlex.quote(
+                        str(write_path(profile, template_dir, keyword_dir_name))
+                    ),
+                ]
             )
 
+            # Override settings for specific keyword
+            for setting_name, setting_value in keyword_settings.items():
+                wake_command.append(shlex.quote(f"{setting_name}={setting_value}"))
+
         probability_threshold = profile.get("wake.raven.probability_threshold")
         if probability_threshold:
             wake_command.extend(["--probability-threshold", str(probability_threshold)])
@@ -733,6 +751,27 @@ def get_wake(
         if minimum_matches:
             wake_command.extend(["--minimum-matches", str(minimum_matches)])
 
+        average_templates = profile.get("wake.raven.average_templates", True)
+        if average_templates:
+            wake_command.append("--average-templates")
+
+        vad_sensitivity = profile.get("wake.raven.vad_sensitivity", 1)
+        if vad_sensitivity:
+            wake_command.extend(["--vad-sensitivity", str(vad_sensitivity)])
+
+        # Positive examples
+        examples_dir = profile.get("wake.raven.examples_dir")
+        if examples_dir:
+            wake_command.extend(
+                ["--examples-dir", shlex.quote(str(write_path(profile, examples_dir)))]
+            )
+
+        examples_format = profile.get("wake.raven.examples_format")
+        if examples_format:
+            wake_command.extend(
+                ["--examples-format", shlex.quote(str(examples_format))]
+            )
+
         add_standard_args(
             profile,
             wake_command,
@@ -1095,6 +1134,13 @@ def get_speech_to_text(
                     ]
                 )
 
+            # ARPA or text FST (G.fst)
+            language_model_type = profile.get(
+                "speech_to_text.kaldi.language_model_type"
+            )
+            if language_model_type:
+                stt_command.extend(["--language-model-type", str(language_model_type)])
+
         base_dictionary = profile.get("speech_to_text.kaldi.base_dictionary")
         if base_dictionary:
             stt_command.extend(
@@ -1827,6 +1873,7 @@ def get_intent_handling(
             _LOGGER.error("handle.command.program is required")
             return []
 
+        user_program = os.path.expandvars(user_program)
         user_command = [user_program] + command_args(
             profile.get("handle.command.arguments", [])
         )
@@ -2188,12 +2235,10 @@ def get_text_to_speech(
 
     if tts_system == "wavenet":
 
-        voice = str(profile.get("text_to_speech.wavenet.voice", "Wavenet-C")).strip()
-        gender = str(profile.get("text_to_speech.wavenet.gender", "FEMALE")).strip()
-        sample_rate = str(profile.get("text_to_speech.wavenet.sample_rate", 22050))
-        language_code = str(
-            profile.get("text_to_speech.wavenet.language_code", "en-US")
+        voice = str(
+            profile.get("text_to_speech.wavenet.voice", "en-US-Wavenet-C")
         ).strip()
+        sample_rate = str(profile.get("text_to_speech.wavenet.sample_rate", 22050))
 
         credentials_json = profile.get("text_to_speech.wavenet.credentials_json")
         if not credentials_json:
@@ -2213,12 +2258,8 @@ def get_text_to_speech(
             shlex.quote(str(write_path(profile, cache_dir))),
             "--voice",
             shlex.quote(voice),
-            "--gender",
-            shlex.quote(gender),
             "--sample-rate",
             shlex.quote(sample_rate),
-            "--language-code",
-            shlex.quote(language_code),
         ]
 
         add_standard_args(
